@@ -12,11 +12,12 @@ pub(crate) enum WeekdayModifier {
     Second,
     Third,
     Fourth,
+    Last,
 }
 
 #[derive(Debug, Clone, Eq, PartialEq)]
-pub(crate) struct DateSpec {
-    pub hours: Vec<Time>,
+pub(crate) struct ParsedSchedule {
+    pub times: Vec<Time>,
     pub days: Option<Vec<(Weekday, Option<WeekdayModifier>)>>,
     pub weeks: Option<WeekVariant>,
 }
